@@ -24,15 +24,16 @@
 #define ARRAYCHANGEMETRICSTEST_H
 
 // Qt
-#include <QObject>
+#include <QtCore/QObject>
 
-namespace Okteta {
+namespace Okteta
+{
 
 class ArrayChangeMetricsTest : public QObject
 {
-    Q_OBJECT
+  Q_OBJECT
 
-private Q_SLOTS: // test functions
+  private Q_SLOTS: // test functions
     void testConstructorAsReplacement();
     void testConstructorAsSwapping();
     void testRevert();
