@@ -2,7 +2,6 @@
  *   This file is part of the Okteta Kasten Framework, made within the KDE community.
  *
  *   Copyright 2012 Alex Richardson <alex.richardson@gmx.de>
- *   Copyright 2016 Aaron Bishop <erroneous@gmail.com>
  *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Lesser General Public
@@ -20,17 +19,16 @@
  *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
-
-#include <QTest>
+#include <QtTest/QtTest>
 #include <QScriptValue>
 #include <QScriptEngine>
 #include <limits>
 
-#include "view/structures/parsers/parserutils.hpp"
+#include "view/structures/parsers/parserutils.h"
 
 class CommonParserTest : public QObject
 {
-    Q_OBJECT
+Q_OBJECT
 
 private Q_SLOTS:
     void testIntFromString();
@@ -88,7 +86,8 @@ void CommonParserTest::testIntFromString()
     ParsedNumber<int> result = ParserUtils::intFromString(str);
     QCOMPARE(result.string, str);
     QCOMPARE(result.isValid, okay);
-    if (result.isValid) {
+    if (result.isValid)
+    {
         QFETCH(int, value);
         QCOMPARE(result.value, value);
     }
@@ -123,7 +122,8 @@ void CommonParserTest::testUIntFromString()
     ParsedNumber<uint> result = ParserUtils::uintFromString(str);
     QCOMPARE(result.string, str);
     QCOMPARE(result.isValid, okay);
-    if (result.isValid) {
+    if (result.isValid)
+    {
         QFETCH(uint, value);
         QCOMPARE(result.value, value);
     }
@@ -135,7 +135,7 @@ void CommonParserTest::testIntFromScriptValue_data()
     QTest::addColumn<bool>("okay");
     QTest::addColumn<int>("value");
 
-    auto* engine = new QScriptEngine(this);
+    QScriptEngine* engine = new QScriptEngine(this);
     QTest::newRow("invalid script value") << QScriptValue() << false;
     QTest::newRow("boolean true") << QScriptValue(true) << false;
     QTest::newRow("boolean false") << QScriptValue(false) << false;
@@ -146,32 +146,32 @@ void CommonParserTest::testIntFromScriptValue_data()
     QTest::newRow("float") << QScriptValue(1234.5) << false;
 
     QTest::newRow("-1234 number") << QScriptValue(-1234) << true << -1234;
-    QTest::newRow("-1234 string") << QScriptValue(QStringLiteral("-1234")) << true << -1234;
+    QTest::newRow("-1234 string") << QScriptValue(QLatin1String("-1234")) << true << -1234;
     QTest::newRow("1234 number") << QScriptValue(1234) << true << 1234;
-    QTest::newRow("1234 string") << QScriptValue(QStringLiteral("1234")) << true << 1234;
+    QTest::newRow("1234 string") << QScriptValue(QLatin1String("1234")) << true << 1234;
     QTest::newRow("0xff number") << QScriptValue(0xff) << true << 0xff;
-    QTest::newRow("0xff string") << QScriptValue(QStringLiteral("0xff")) << true << 0xff;
+    QTest::newRow("0xff string") << QScriptValue(QLatin1String("0xff")) << true << 0xff;
     QTest::newRow("-0xff number") << QScriptValue(-0xff) << true << -0xff;
-    QTest::newRow("-0xff string") << QScriptValue(QStringLiteral("-0xff")) << true << -0xff;
+    QTest::newRow("-0xff string") << QScriptValue(QLatin1String("-0xff")) << true << -0xff;
 
     int maxInt = 0x7fffffff;
     QTEST_ASSERT(maxInt == std::numeric_limits<int>::max());
     QTest::newRow("max int") << QScriptValue(maxInt) << true << maxInt;
     QTest::newRow("max double") << QScriptValue(double(maxInt)) << true << maxInt;
-    QTest::newRow("max string") << QScriptValue(QStringLiteral("2147483647")) << true << maxInt;
-    QTest::newRow("max hex string") << QScriptValue(QStringLiteral("0x7fffffff")) << true << maxInt;
-    // to int32 wraps around
+    QTest::newRow("max string") << QScriptValue(QLatin1String("2147483647")) << true << maxInt;
+    QTest::newRow("max hex string") << QScriptValue(QLatin1String("0x7fffffff")) << true << maxInt;
+    //to int32 wraps around
     QTest::newRow("max+1") << QScriptValue(double(maxInt) + 1) << false;
-    QTest::newRow("max+1 string") << QScriptValue(QStringLiteral("2147483648")) << false;
-    QTest::newRow("max+1 hex string") << QScriptValue(QStringLiteral("0x80000000")) << false;
+    QTest::newRow("max+1 string") << QScriptValue(QLatin1String("2147483648")) << false;
+    QTest::newRow("max+1 hex string") << QScriptValue(QLatin1String("0x80000000")) << false;
     QTest::newRow("max+2") << QScriptValue(double(maxInt) + 2) << false;
 
     int minInt = -0x80000000;
     QTEST_ASSERT(minInt == std::numeric_limits<int>::min());
     QTest::newRow("min int") << QScriptValue(minInt) << true << minInt;
     QTest::newRow("min double") << QScriptValue(double(minInt)) << true << minInt;
-    QTest::newRow("min string") << QScriptValue(QStringLiteral("-2147483648")) << true << minInt;
-    QTest::newRow("min hex string") << QScriptValue(QStringLiteral("-0x80000000")) << true << minInt;
+    QTest::newRow("min string") << QScriptValue(QLatin1String("-2147483648")) << true << minInt;
+    QTest::newRow("min hex string") << QScriptValue(QLatin1String("-0x80000000")) << true << minInt;
     QTest::newRow("min-1") << QScriptValue(double(minInt) - 1) << false;
     QTest::newRow("large number") << QScriptValue(double(0x123456789a)) << false;
 
@@ -184,12 +184,14 @@ void CommonParserTest::testIntFromScriptValue()
 
     ParsedNumber<int> result = ParserUtils::intFromScriptValue(scriptValue);
     QCOMPARE(result.string, scriptValue.toString());
-    if (result.isValid != okay) {
+    if (result.isValid != okay)
+    {
         qDebug() << scriptValue.toString() << ", int =" << scriptValue.toInt32() << ", double = "
-                 << scriptValue.toNumber();
+                << scriptValue.toNumber();
     }
     QCOMPARE(result.isValid, okay);
-    if (result.isValid) {
+    if (result.isValid)
+    {
         QFETCH(int, value);
         QCOMPARE(result.value, value);
     }
@@ -201,7 +203,7 @@ void CommonParserTest::testUIntFromScriptValue_data()
     QTest::addColumn<bool>("okay");
     QTest::addColumn<uint>("value");
 
-    auto* engine = new QScriptEngine(this);
+    QScriptEngine* engine = new QScriptEngine(this);
     QTest::newRow("invalid script value") << QScriptValue() << false;
     QTest::newRow("boolean true") << QScriptValue(true) << false;
     QTest::newRow("boolean false") << QScriptValue(false) << false;
@@ -212,22 +214,22 @@ void CommonParserTest::testUIntFromScriptValue_data()
     QTest::newRow("float") << QScriptValue(1234.5) << false;
 
     QTest::newRow("1234 number") << QScriptValue(1234) << true << 1234u;
-    QTest::newRow("1234 string") << QScriptValue(QStringLiteral("1234")) << true << 1234u;
+    QTest::newRow("1234 string") << QScriptValue(QLatin1String("1234")) << true << 1234u;
     QTest::newRow("0xff number") << QScriptValue(0xff) << true << 0xffu;
-    QTest::newRow("0xff string") << QScriptValue(QStringLiteral("0xff")) << true << 0xffu;
+    QTest::newRow("0xff string") << QScriptValue(QLatin1String("0xff")) << true << 0xffu;
 
-    QTest::newRow("negative string") << QScriptValue(QStringLiteral("-1")) << false;
+    QTest::newRow("negative string") << QScriptValue(QLatin1String("-1")) << false;
     QTest::newRow("negative number") << QScriptValue(-1) << false;
 
     uint maxInt = 0xffffffff;
     QTEST_ASSERT(maxInt == std::numeric_limits<uint>::max());
     QTest::newRow("max") << QScriptValue(double(maxInt)) << true << maxInt;
     QTest::newRow("max int") << QScriptValue(maxInt) << true << maxInt;
-    QTest::newRow("max string") << QScriptValue(QStringLiteral("4294967295")) << true << maxInt;
-    QTest::newRow("max hex string") << QScriptValue(QStringLiteral("0xffffffff")) << true << maxInt;
+    QTest::newRow("max string") << QScriptValue(QLatin1String("4294967295")) << true << maxInt;
+    QTest::newRow("max hex string") << QScriptValue(QLatin1String("0xffffffff")) << true << maxInt;
     QTest::newRow("max+1") << QScriptValue(double(maxInt) + 1) << false;
-    QTest::newRow("max+1 string") << QScriptValue(QStringLiteral("4294967296")) << false;
-    QTest::newRow("max+1 hex string") << QScriptValue(QStringLiteral("0x100000000")) << false;
+    QTest::newRow("max+1 string") << QScriptValue(QLatin1String("4294967296")) << false;
+    QTest::newRow("max+1 hex string") << QScriptValue(QLatin1String("0x100000000")) << false;
     QTest::newRow("large number") << QScriptValue(double(0x123456789a)) << false;
 }
 
@@ -238,12 +240,14 @@ void CommonParserTest::testUIntFromScriptValue()
 
     ParsedNumber<uint> result = ParserUtils::uintFromScriptValue(scriptValue);
     QCOMPARE(result.string, scriptValue.toString());
-    if (result.isValid != okay) {
+    if (result.isValid != okay)
+    {
         qDebug() << scriptValue.toString() << ", uint =" << scriptValue.toUInt32() << ", double = "
-                 << scriptValue.toNumber();
+                << scriptValue.toNumber();
     }
     QCOMPARE(result.isValid, okay);
-    if (result.isValid) {
+    if (result.isValid)
+    {
         QFETCH(uint, value);
         QCOMPARE(result.value, value);
     }
@@ -255,7 +259,7 @@ inline void CommonParserTest::testToStringEncoding()
     QFETCH(int, expected);
     QScopedPointer<ScriptLogger> logger(new ScriptLogger());
     StringDataInformation::StringType type =
-        ParserUtils::toStringEncoding(str, LoggerWithContext(logger.data(), QString()));
+            ParserUtils::toStringEncoding(str, LoggerWithContext(logger.data(), QString()));
     QCOMPARE((int)type, expected);
 }
 
@@ -264,40 +268,40 @@ inline void CommonParserTest::testToStringEncoding_data()
     QTest::addColumn<QString>("str");
     QTest::addColumn<int>("expected");
 
-    QTest::newRow("ascii") << "ascii" << (int)StringDataInformation::StringType::ASCII;
-    QTest::newRow("ebcdic") << "ebcdic" << (int)StringDataInformation::StringType::EBCDIC;
-    QTest::newRow("ascii upper") << "ASCII" << (int)StringDataInformation::StringType::ASCII;
-    QTest::newRow("excess char") << "asciii" << (int)StringDataInformation::StringType::InvalidEncoding;
+    QTest::newRow("ascii") << "ascii" << (int)StringDataInformation::ASCII;
+    QTest::newRow("ascii upper") << "ASCII" << (int)StringDataInformation::ASCII;
+    QTest::newRow("excess char") << "asciii" << (int)StringDataInformation::InvalidEncoding;
 
-    QTest::newRow("latin1") << "latin1" << (int)StringDataInformation::StringType::Latin1;
-    QTest::newRow("latin-1") << "latin-1" << (int)StringDataInformation::StringType::Latin1;
-    QTest::newRow("latin") << "latin" << (int)StringDataInformation::StringType::InvalidEncoding;
+    QTest::newRow("latin1") << "latin1" << (int)StringDataInformation::Latin1;
+    QTest::newRow("latin-1") << "latin-1" << (int)StringDataInformation::Latin1;
+    QTest::newRow("latin") << "latin" << (int)StringDataInformation::InvalidEncoding;
 
-    QTest::newRow("utf8") << "utf8" << (int)StringDataInformation::StringType::UTF8;
-    QTest::newRow("utf-8") << "utf-8" << (int)StringDataInformation::StringType::UTF8;
-    QTest::newRow("utf--8") << "utf--8" << (int)StringDataInformation::StringType::InvalidEncoding;
+    QTest::newRow("utf8") << "utf8" << (int)StringDataInformation::UTF8;
+    QTest::newRow("utf-8") << "utf-8" << (int)StringDataInformation::UTF8;
+    QTest::newRow("utf--8") << "utf--8" << (int)StringDataInformation::InvalidEncoding;
 
-    QTest::newRow("utf16") << "utf16" << (int)StringDataInformation::StringType::UTF16_LE;
-    QTest::newRow("utf-16") << "utf-16" << (int)StringDataInformation::StringType::UTF16_LE;
-    QTest::newRow("utf-16le") << "utf-16le" << (int)StringDataInformation::StringType::UTF16_LE;
-    QTest::newRow("utf-16-le") << "utf-16-le" << (int)StringDataInformation::StringType::UTF16_LE;
-    QTest::newRow("utf-16--le") << "utf-16--le" << (int)StringDataInformation::StringType::InvalidEncoding;
+    QTest::newRow("utf16") << "utf16" << (int)StringDataInformation::UTF16_LE;
+    QTest::newRow("utf-16") << "utf-16" << (int)StringDataInformation::UTF16_LE;
+    QTest::newRow("utf-16le") << "utf-16le" << (int)StringDataInformation::UTF16_LE;
+    QTest::newRow("utf-16-le") << "utf-16-le" << (int)StringDataInformation::UTF16_LE;
+    QTest::newRow("utf-16--le") << "utf-16--le" << (int)StringDataInformation::InvalidEncoding;
 
-    QTest::newRow("utf-16be") << "utf-16be" << (int)StringDataInformation::StringType::UTF16_BE;
-    QTest::newRow("utf-16-be") << "utf-16-be" << (int)StringDataInformation::StringType::UTF16_BE;
-    QTest::newRow("utf-16-abe") << "utf-16-abe" << (int)StringDataInformation::StringType::InvalidEncoding;
+    QTest::newRow("utf-16be") << "utf-16be" << (int)StringDataInformation::UTF16_BE;
+    QTest::newRow("utf-16-be") << "utf-16-be" << (int)StringDataInformation::UTF16_BE;
+    QTest::newRow("utf-16-abe") << "utf-16-abe" << (int)StringDataInformation::InvalidEncoding;
 
-    QTest::newRow("utf32") << "utf32" << (int)StringDataInformation::StringType::UTF32_LE;
-    QTest::newRow("utf-32") << "utf-32" << (int)StringDataInformation::StringType::UTF32_LE;
-    QTest::newRow("utf-32le") << "utf-32le" << (int)StringDataInformation::StringType::UTF32_LE;
-    QTest::newRow("utf-32-le") << "utf-32-le" << (int)StringDataInformation::StringType::UTF32_LE;
-    QTest::newRow("utf-32--le") << "utf-32--le" << (int)StringDataInformation::StringType::InvalidEncoding;
+    QTest::newRow("utf32") << "utf32" << (int)StringDataInformation::UTF32_LE;
+    QTest::newRow("utf-32") << "utf-32" << (int)StringDataInformation::UTF32_LE;
+    QTest::newRow("utf-32le") << "utf-32le" << (int)StringDataInformation::UTF32_LE;
+    QTest::newRow("utf-32-le") << "utf-32-le" << (int)StringDataInformation::UTF32_LE;
+    QTest::newRow("utf-32--le") << "utf-32--le" << (int)StringDataInformation::InvalidEncoding;
 
-    QTest::newRow("utf-32be") << "utf-32be" << (int)StringDataInformation::StringType::UTF32_BE;
-    QTest::newRow("utf-32-be") << "utf-32-be" << (int)StringDataInformation::StringType::UTF32_BE;
-    QTest::newRow("utf-32-abe") << "utf-32-abe" << (int)StringDataInformation::StringType::InvalidEncoding;
+    QTest::newRow("utf-32be") << "utf-32be" << (int)StringDataInformation::UTF32_BE;
+    QTest::newRow("utf-32-be") << "utf-32-be" << (int)StringDataInformation::UTF32_BE;
+    QTest::newRow("utf-32-abe") << "utf-32-abe" << (int)StringDataInformation::InvalidEncoding;
 }
 
-QTEST_GUILESS_MAIN(CommonParserTest)
+QTEST_MAIN(CommonParserTest)
+
 
 #include "commonparsertest.moc"
