@@ -24,30 +24,32 @@
 #define BINARY8_H
 
 // Qt
-#include <QMetaType>
-#include <QString>
+#include <QtCore/QMetaType>
+#include <QtCore/QString>
+
 
 struct Binary8
 {
-public:
-    Binary8(quint8 v);
+  public:
+    Binary8( quint8 v );
     Binary8();
 
-public:
+  public:
     QString toString() const;
 
-public:
-    quint8 value = 0;
+  public:
+    quint8 value;
 };
 
-inline Binary8::Binary8() = default;
-inline Binary8::Binary8(quint8 v) : value(v) {}
+
+inline Binary8::Binary8() : value( 0 ) {}
+inline Binary8::Binary8( quint8 v ) : value( v ) {}
 
 inline QString Binary8::toString() const
 {
-    return QStringLiteral("%1").arg(value, 8, 2, QChar::fromLatin1('0'));
+    return QString::fromLatin1( "%1" ).arg( value, 8, 2, QChar::fromLatin1('0') );
 }
 
-Q_DECLARE_METATYPE(Binary8)
+Q_DECLARE_METATYPE( Binary8 )
 
 #endif
