@@ -30,12 +30,12 @@ class QScriptContext;
 class QScriptEngine;
 union AllPrimitiveTypes;
 
-namespace ScriptUtils {
+namespace ScriptUtils
+{
+    QString qScriptValueToString(const QScriptValue& val);
 
-QString qScriptValueToString(const QScriptValue& val);
-
-void wrapAllPrimitiveTypes(QScriptValue& out, AllPrimitiveTypes allPrim,
-                           PrimitiveDataType actualType);
+    void wrapAllPrimitiveTypes(QScriptValue& out, AllPrimitiveTypes allPrim,
+            PrimitiveDataType actualType);
 
 }
 
